@@ -41,7 +41,7 @@
 /**                                                        **/
 /**   DATES      : # Version 6.0  : from : 30 apr 2015     **/
 /**                                 to   : 15 may 2018     **/
-/**                # Version 7.0  : from : 17 jan 2023     **/
+/**                # Version 7.0  : from : 18 feb 2018     **/
 /**                                 to   : 17 jan 2023     **/
 /**                                                        **/
 /************************************************************/
@@ -844,22 +844,3 @@ const ArchDeco2Dom * const  dom1ptr)
 
   return (0);
 }
-
-/* This function creates the MPI_Datatype for
-** decomposition-described domains.
-** It returns:
-** - 0  : if type could be created.
-** - 1  : on error.
-*/
-
-#ifdef SCOTCH_PTSCOTCH
-int
-archDeco2DomMpiType (
-const ArchDeco2 * const       archptr,
-MPI_Datatype * const          typeptr)
-{
-  *typeptr = ANUM_MPI;
-
-  return (0);
-}
-#endif /* SCOTCH_PTSCOTCH */
