@@ -1,4 +1,4 @@
-/* Copyright 2004,2007,2008,2010,2012,2015,2018,2021,2023 IPB, Universite de Bordeaux, INRIA & CNRS
+/* Copyright 2004,2007,2008,2010,2012,2015,2018,2021,2023,2024 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -51,7 +51,7 @@
 /**                # Version 6.1  : from : 24 jun 2021     **/
 /**                                 to   : 24 jun 2021     **/
 /**                # Version 7.0  : from : 19 jan 2023     **/
-/**                                 to   : 19 jan 2023     **/
+/**                                 to   : 08 sep 2024     **/
 /**                                                        **/
 /************************************************************/
 
@@ -94,7 +94,7 @@ static void *               memorycheckwtchval = NULL; /* Block address to watch
 #ifdef COMMON_MEMORY_CHECK
 
 static
-void
+int
 memCheckBlock (
 void *            blokptr)
 {
@@ -102,8 +102,10 @@ void *            blokptr)
   char *              zoneend;
   int                 zoneidx;
   size_t              bloksiz;
+  int                 o;
 
-  bloksiz = *((size_t *) blokptr);
+  o = 0;                                          /* Assume no error     */
+  bloksiz = *((size_t *) blokptr);                /* Get real block size */
 
   for (zoneptr = (char *) blokptr + COMMON_MEMORY_SZSP, /* Check "before" sentinel */
        zoneend = (char *) blokptr + MEMORY_CHECK_BORDER, zoneidx = 0;
@@ -112,6 +114,7 @@ void *            blokptr)
       errorPrintW ("memoryCheck: error before block at %p, real size %ld",
                    (char *) blokptr + MEMORY_CHECK_BORDER,
                    (long) bloksiz);
+      o = 1;                                      /* Error detected */
       break;
     }
   }
@@ -123,18 +126,26 @@ void *            blokptr)
       errorPrintW ("memoryCheck: error after block at %p, real size %ld",
                    (char *) blokptr + MEMORY_CHECK_BORDER,
                    (long) bloksiz);
+      o = 1;                                      /* Error detected */
       break;
     }
   }
+
+  return (o);
 }
 
 int
 memCheck ()
 {
   int                 bloknum;
+  int                 o;
+
+  o = 0;                                          /* Assume no error */
 
   for (bloknum = 0; bloknum < memorycheckbloknbr; bloknum ++)
-    memCheckBlock (memorycheckbloktab[bloknum]);
+    o |= memCheckBlock (memorycheckbloktab[bloknum]);
+
+  return (o);
 }
 
 int
