@@ -1,4 +1,4 @@
-/* Copyright 2004,2007,2018,2019-2020,2023 IPB, Universite de Bordeaux, INRIA & CNRS
+/* Copyright 2004,2007,2018,2019-2020,2023,2024 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -54,7 +54,7 @@
 /**                # Version 6.1  : from : 11 nov 2019     **/
 /**                                 to   : 11 feb 2020     **/
 /**                # Version 7.0  : from : 19 jan 2023     **/
-/**                                 to   : 19 jan 2023     **/
+/**                                 to   : 11 sep 2024     **/
 /**                                                        **/
 /************************************************************/
 
@@ -87,7 +87,7 @@
 
 int
 hgraphOrderHd (
-const Hgraph * restrict const             grafptr,
+Hgraph * restrict const                   grafptr,
 Order * restrict const                    ordeptr,
 const Gnum                                ordenum, /*+ Zero-based ordering number +*/
 OrderCblk * restrict const                cblkptr, /*+ Multiple column-block      +*/
@@ -135,7 +135,7 @@ const HgraphOrderHdParam * restrict const paraptr)
                      &nexttab, (size_t) (n           * sizeof (Gnum)),
                      &cwgttax, (size_t) (cwgtsiz     * sizeof (Gnum)), NULL) == NULL) { /* Not based yet */
     errorPrint ("hgraphOrderHd: out of memory");
-    return     (1);
+    return (1);
   }
 
   hgraphOrderHxFill (grafptr, petab, lentab, iwtab, nvartab, elentab, &pfree);
@@ -146,7 +146,7 @@ const HgraphOrderHdParam * restrict const paraptr)
   if (ncmpa < 0) {
     errorPrint ("hgraphOrderHd: internal error");
     memFree    (petab);                           /* Free group leader */
-    return     (1);
+    return (1);
   }
 
   if (grafptr->s.velotax != NULL) {
