@@ -1,4 +1,4 @@
-/* Copyright 2007-2010,2012,2018,2021,2023 IPB, Universite de Bordeaux, INRIA & CNRS
+/* Copyright 2007-2010,2012,2018,2021,2023,2024 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -48,7 +48,7 @@
 /**                # Version 6.1  : from : 15 mar 2021     **/
 /**                                 to   : 15 mar 2021     **/
 /**                # Version 7.0  : from : 21 jan 2023     **/
-/**                                 to   : 21 jan 2023     **/
+/**                                 to   : 09 aug 2024     **/
 /**                                                        **/
 /************************************************************/
 
@@ -168,12 +168,12 @@ MPI_Fint * const            commptr),   \
                      &vertloctab, &vendloctab, &veloloctab, &vlblloctab,
                      edgeglbptr, edgelocptr, edgelocptz,
                      &edgeloctab, &edgegsttab, &edloloctab, &commdat);
-  *vertlocidx = (vertloctab - indxptr) + 1;       /* Add 1 since Fortran indices start at 1 */
-  *vendlocidx = (vendloctab - indxptr) + 1;
-  *velolocidx = (veloloctab != NULL) ? (veloloctab - indxptr) + 1 : *vertlocidx;
-  *vlbllocidx = (vlblloctab != NULL) ? (vlblloctab - indxptr) + 1 : *vertlocidx;
-  *edgelocidx = (edgeloctab - indxptr) + 1;
-  *edgegstidx = (edgegsttab != NULL) ? (edgegsttab - indxptr) + 1 : *vertlocidx;
-  *edlolocidx = (edloloctab != NULL) ? (edloloctab - indxptr) + 1 : *vertlocidx;
+  *vertlocidx = (SCOTCH_Idx) (vertloctab - indxptr) + 1; /* Add 1 since Fortran indices start at 1 */
+  *vendlocidx = (SCOTCH_Idx) (vendloctab - indxptr) + 1;
+  *velolocidx = (veloloctab != NULL) ? (SCOTCH_Idx) (veloloctab - indxptr) + 1 : *vertlocidx;
+  *vlbllocidx = (vlblloctab != NULL) ? (SCOTCH_Idx) (vlblloctab - indxptr) + 1 : *vertlocidx;
+  *edgelocidx = (SCOTCH_Idx) (edgeloctab - indxptr) + 1;
+  *edgegstidx = (edgegsttab != NULL) ? (SCOTCH_Idx) (edgegsttab - indxptr) + 1 : *vertlocidx;
+  *edlolocidx = (edloloctab != NULL) ? (SCOTCH_Idx) (edloloctab - indxptr) + 1 : *vertlocidx;
   *commptr = MPI_Comm_c2f (commdat);
 }
