@@ -1,4 +1,4 @@
-/* Copyright 2004,2007-2012,2019,2021,2023,2024 IPB, Universite de Bordeaux, INRIA & CNRS
+/* Copyright 2004,2007-2012,2019,2021,2023-2025 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -58,7 +58,7 @@
 /**                # Version 6.1  : from : 15 mar 2021     **/
 /**                                 to   : 15 mar 2021     **/
 /**                # Version 7.0  : from : 27 aug 2019     **/
-/**                                 to   : 28 jul 2024     **/
+/**                                 to   : 09 jan 2025     **/
 /**                                                        **/
 /************************************************************/
 
@@ -69,9 +69,9 @@
 **  The defines and includes.
 */
 
-#ifndef SCOTCH_H
+#ifndef LIB_SCOTCH_H
 #include "scotch.h"
-#endif /* SCOTCH_H */
+#endif /* LIB_SCOTCH_H */
 
 /*
 **  The type and structure definitions.
@@ -104,10 +104,14 @@
 #define SCOTCH_DGRAPHBUILDGRID3DEDGELOAD 8
 #endif /* SCOTCH_DGRAPHBUILDGRID3DMESH */
 
+/*+ Integer type. +*/
+
+#define SCOTCH_NUM_MPI DUMMYINTMPI
+
 /*+ Opaque objects. The dummy sizes of these
 objects, computed at compile-time by program
 "dummysizes", are given as double values for
-proper padding                               +*/
+proper padding.                              +*/
 
 typedef struct {
   double                    dummy[DUMMYSIZEDGRAPH];
@@ -165,6 +169,7 @@ int                         SCOTCH_dgraphHaloWait (SCOTCH_DgraphHaloReq * const)
 int                         SCOTCH_dgraphMapInit (const SCOTCH_Dgraph * const, SCOTCH_Dmapping * const, const SCOTCH_Arch * const, SCOTCH_Num * const);
 void                        SCOTCH_dgraphMapExit (const SCOTCH_Dgraph * const, SCOTCH_Dmapping * const);
 int                         SCOTCH_dgraphMapSave (const SCOTCH_Dgraph * const, const SCOTCH_Dmapping * const, FILE * const);
+int                         SCOTCH_dgraphMapStat (SCOTCH_Dgraph * const, const SCOTCH_Dmapping * const, SCOTCH_Num * const, SCOTCH_Num * const, SCOTCH_Num * const, SCOTCH_Num * const, double * const, double * const, SCOTCH_Num * const, SCOTCH_Num * const, SCOTCH_Num * const, SCOTCH_Num * const, SCOTCH_Num [256], SCOTCH_Num * const, SCOTCH_Num * const, SCOTCH_Num * const);
 int                         SCOTCH_dgraphMapView (SCOTCH_Dgraph * const, const SCOTCH_Dmapping * const, FILE * const);
 int                         SCOTCH_dgraphMapCompute (SCOTCH_Dgraph * const, SCOTCH_Dmapping * const, SCOTCH_Strat * const);
 int                         SCOTCH_dgraphMap     (SCOTCH_Dgraph * const, const SCOTCH_Arch * const, SCOTCH_Strat * const, SCOTCH_Num * const);
