@@ -1,4 +1,4 @@
-/* Copyright 2004,2007-2016,2018-2024 IPB, Universite de Bordeaux, INRIA & CNRS
+/* Copyright 2004,2007-2016,2018-2025 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -54,8 +54,8 @@
 /**                                 to   : 24 aug 2020     **/
 /**                # Version 6.1  : from : 24 aug 2020     **/
 /**                                 to   : 30 dec 2021     **/
-/**                # Version 7.0  : from : 02 mar 2018     **/
-/**                                 to   : 02 aug 2024     **/
+/**                # Version 7.0  : from : 19 feb 2018     **/
+/**                                 to   : 31 jan 2025     **/
 /**                                                        **/
 /************************************************************/
 
@@ -63,7 +63,7 @@
 ** Version and copyright strings.
 */
 
-#define SCOTCH_COPYRIGHT_STRING     "Copyright 1992-2024 IPB, Universite de Bordeaux, INRIA & CNRS, France"
+#define SCOTCH_COPYRIGHT_STRING     "Copyright 1992-2025 IPB, Universite de Bordeaux, INRIA & CNRS, France"
 #define SCOTCH_LICENSE_STRING       "This software is libre/free software under CeCILL-C -- see the user's manual for more information"
 #ifdef SCOTCH_CODENAME
 #define SCOTCH_VERSION_STRING       STRINGIFY (SCOTCH_VERSION) "." STRINGIFY (SCOTCH_RELEASE) "." STRINGIFY (SCOTCH_PATCHLEVEL) " (" STRINGIFY (SCOTCH_CODENAME) ")"
@@ -239,6 +239,11 @@
 #define SCOTCH_NAME_PREFIX_INTERN   _SCOTCH
 #define SCOTCH_NAME_PREFIX_PUBLICFL scotchf
 #define SCOTCH_NAME_PREFIX_PUBLICFU SCOTCHF
+#ifdef SCOTCH_RENAME
+#ifndef SCOTCH_COMMON_RENAME
+#define SCOTCH_COMMON_RENAME
+#endif /* SCOTCH_COMMON_RENAME */
+#endif /* SCOTCH_RENAME */
 
 #define SCOTCH_NAME_GLUE2(n,s)      n##s
 #define SCOTCH_NAME_GLUE3(p,n,s)    p##n##s
@@ -284,14 +289,14 @@
 #define SCOTCH_Strat                SCOTCH_NAME_PUBLIC (SCOTCH_Strat)
 #endif /* SCOTCH_RENAME */
 
-#if ((! defined SCOTCH_COMMON_EXTERNAL) || (defined SCOTCH_COMMON_RENAME))
-#define errorPrint                  SCOTCH_NAME_MACRO2 (SCOTCH_, errorPrint) /* Same name whatever the suffix is since external library */
-#define errorPrintW                 SCOTCH_NAME_MACRO2 (SCOTCH_, errorPrintW)
-#define errorProg                   SCOTCH_NAME_MACRO2 (SCOTCH_, errorProg)
-
-#define memCur                      SCOTCH_NAME_MACRO2 (SCOTCH_, memCur)
-#define memMax                      SCOTCH_NAME_MACRO2 (SCOTCH_, memMax)
+#ifdef SCOTCH_COMMON_RENAME
+#define SCOTCH_NAME_GLOBAL(n)       SCOTCH_NAME_MACRO2 (SCOTCH_, n) /* Same name whatever the suffix is, since external library */
+#define errorPrint                  SCOTCH_NAME_GLOBAL (errorPrint)
+#define errorPrintW                 SCOTCH_NAME_GLOBAL (errorPrintW)
+#define errorProg                   SCOTCH_NAME_GLOBAL (errorProg)
+#endif /* SCOTCH_COMMON_RENAME */
 
+#if ((defined SCOTCH_COMMON_RENAME) && ! (defined SCOTCH_COMMON_INTERNAL))
 #define clockGet                    SCOTCH_NAME_INTERN (clockGet)
 
 #define commonStubDummy             SCOTCH_NAME_INTERN (commonStubDummy)
@@ -299,6 +304,7 @@
 #define contextCommit               SCOTCH_NAME_INTERN (contextCommit)
 #define contextExit                 SCOTCH_NAME_INTERN (contextExit)
 #define contextInit                 SCOTCH_NAME_INTERN (contextInit)
+#define contextOptionsInit          SCOTCH_NAME_INTERN (contextOptionsInit)
 #define contextRandomClone          SCOTCH_NAME_INTERN (contextRandomClone)
 #define contextThreadInit           SCOTCH_NAME_INTERN (contextThreadInit)
 #define contextThreadInit2          SCOTCH_NAME_INTERN (contextThreadInit2)
@@ -354,7 +360,9 @@
 #define memCheckSize                SCOTCH_NAME_INTERN (memCheckSize)
 #define memCheckToggle              SCOTCH_NAME_INTERN (memCheckToggle)
 #define memCheckWatch               SCOTCH_NAME_INTERN (memCheckWatch)
+#define memCur                      SCOTCH_NAME_INTERN (memCur)
 #define memFreeRecord               SCOTCH_NAME_INTERN (memFreeRecord)
+#define memMax                      SCOTCH_NAME_INTERN (memMax)
 #define memReallocGroup             SCOTCH_NAME_INTERN (memReallocGroup)
 #define memReallocRecord            SCOTCH_NAME_INTERN (memReallocRecord)
 #define memOffset                   SCOTCH_NAME_INTERN (memOffset)
@@ -381,7 +389,7 @@
 #define timerVal                    SCOTCH_NAME_INTERN (timerVal)
 
 #define usagePrint                  SCOTCH_NAME_INTERN (usagePrint)
-#endif /* ((! defined SCOTCH_COMMON_EXTERNAL) || (defined SCOTCH_COMMON_RENAME)) */
+#endif /* ((defined SCOTCH_COMMON_RENAME) && ! (defined SCOTCH_COMMON_INTERNAL)) */
 
 #ifdef SCOTCH_RENAME
 #define archInit                    SCOTCH_NAME_INTERN (archInit)
@@ -392,6 +400,7 @@
 /* #define archName                 SCOTCH_NAME_INTERN (archName) Already a macro */
 #define archClass                   SCOTCH_NAME_INTERN (archClass)
 #define archClass2                  SCOTCH_NAME_INTERN (archClass2)
+#define archClassNum                SCOTCH_NAME_INTERN (archClassNum)
 #define archClassTab                SCOTCH_NAME_INTERN (archClassTab)
 #define archDomLoad                 SCOTCH_NAME_INTERN (archDomLoad)
 #define archDomSave                 SCOTCH_NAME_INTERN (archDomSave)
@@ -406,6 +415,7 @@
 #define archDomBipart               SCOTCH_NAME_INTERN (archDomBipart)
 #endif /* SCOTCH_DEBUG_ARCH2 */
 #define archDomMpiType              SCOTCH_NAME_INTERN (archDomMpiType)
+#define archDomMpiTypeAnum          SCOTCH_NAME_INTERN (archDomMpiTypeAnum)
 #define archBuild                   SCOTCH_NAME_INTERN (archBuild)
 #define archCmpltArchLoad           SCOTCH_NAME_INTERN (archCmpltArchLoad)
 #define archCmpltArchSave           SCOTCH_NAME_INTERN (archCmpltArchSave)
@@ -719,8 +729,6 @@
 #define commGatherv                 SCOTCH_NAME_INTERN (commGatherv)
 #define commScatterv                SCOTCH_NAME_INTERN (commScatterv)
 
-#define contextOptionsInit          SCOTCH_NAME_INTERN (contextOptionsInit)
-
 #define dgraphAllreduceMaxSum2      SCOTCH_NAME_INTERN (dgraphAllreduceMaxSum2)
 #define dgraphBuild                 SCOTCH_NAME_INTERN (dgraphBuild)
 #define dgraphBuild2                SCOTCH_NAME_INTERN (dgraphBuild2)
@@ -1022,6 +1030,7 @@
 #define stratCondEval               SCOTCH_NAME_INTERN (stratCondEval)
 #define stratCondExit               SCOTCH_NAME_INTERN (stratCondExit)
 #define stratCondSave               SCOTCH_NAME_INTERN (stratCondSave)
+#define stratParserBegin            SCOTCH_NAME_INTERN (stratParserBegin)
 #define stratParserInit             SCOTCH_NAME_INTERN (stratParserInit)
 #define stratParserInput            SCOTCH_NAME_INTERN (stratParserInput)
 #define stratParserLex              SCOTCH_NAME_INTERN (stratParserLex)
@@ -1119,7 +1128,14 @@
 #define SCOTCH_archCmplt            SCOTCH_NAME_PUBLIC (SCOTCH_archCmplt)
 #define SCOTCH_archCmpltw           SCOTCH_NAME_PUBLIC (SCOTCH_archCmpltw)
 #define SCOTCH_archDomAlloc         SCOTCH_NAME_PUBLIC (SCOTCH_archDomAlloc)
+#define SCOTCH_archDomBipart        SCOTCH_NAME_PUBLIC (SCOTCH_archDomBipart)
+#define SCOTCH_archDomDist          SCOTCH_NAME_PUBLIC (SCOTCH_archDomDist)
+#define SCOTCH_archDomFrst          SCOTCH_NAME_PUBLIC (SCOTCH_archDomFrst)
+#define SCOTCH_archDomNum           SCOTCH_NAME_PUBLIC (SCOTCH_archDomNum)
 #define SCOTCH_archDomSizeof        SCOTCH_NAME_PUBLIC (SCOTCH_archDomSizeof)
+#define SCOTCH_archDomSize          SCOTCH_NAME_PUBLIC (SCOTCH_archDomSize)
+#define SCOTCH_archDomTerm          SCOTCH_NAME_PUBLIC (SCOTCH_archDomTerm)
+#define SCOTCH_archDomWght          SCOTCH_NAME_PUBLIC (SCOTCH_archDomWght)
 #define SCOTCH_archExit             SCOTCH_NAME_PUBLIC (SCOTCH_archExit)
 #define SCOTCH_archHcub             SCOTCH_NAME_PUBLIC (SCOTCH_archHcub)
 #define SCOTCH_archInit             SCOTCH_NAME_PUBLIC (SCOTCH_archInit)
@@ -1140,6 +1156,19 @@
 #define SCOTCH_archVar              SCOTCH_NAME_PUBLIC (SCOTCH_archVar)
 #define SCOTCH_archVcmplt           SCOTCH_NAME_PUBLIC (SCOTCH_archVcmplt)
 #define SCOTCH_archVhcub            SCOTCH_NAME_PUBLIC (SCOTCH_archVhcub)
+#define SCOTCH_contextBindGraph     SCOTCH_NAME_PUBLIC (SCOTCH_contextBindGraph)
+#define SCOTCH_contextBindMesh      SCOTCH_NAME_PUBLIC (SCOTCH_contextBindMesh)
+#define SCOTCH_contextExit          SCOTCH_NAME_PUBLIC (SCOTCH_contextExit)
+#define SCOTCH_contextInit          SCOTCH_NAME_PUBLIC (SCOTCH_contextInit)
+#define SCOTCH_contextOptionGetNum  SCOTCH_NAME_PUBLIC (SCOTCH_contextOptionGetNum)
+#define SCOTCH_contextOptionSetNum  SCOTCH_NAME_PUBLIC (SCOTCH_contextOptionSetNum)
+#define SCOTCH_contextRandomClone   SCOTCH_NAME_PUBLIC (SCOTCH_contextRandomClone)
+#define SCOTCH_contextRandomReset   SCOTCH_NAME_PUBLIC (SCOTCH_contextRandomReset)
+#define SCOTCH_contextRandomSeed    SCOTCH_NAME_PUBLIC (SCOTCH_contextRandomSeed)
+#define SCOTCH_contextThreadImport1 SCOTCH_NAME_PUBLIC (SCOTCH_contextThreadImport1)
+#define SCOTCH_contextThreadImport2 SCOTCH_NAME_PUBLIC (SCOTCH_contextThreadImport2)
+#define SCOTCH_contextThreadSpawn   SCOTCH_NAME_PUBLIC (SCOTCH_contextThreadSpawn)
+#define SCOTCH_contextSizeof        SCOTCH_NAME_PUBLIC (SCOTCH_contextSizeof)
 #define SCOTCH_dgraphAlloc          SCOTCH_NAME_PUBLIC (SCOTCH_dgraphAlloc)
 #define SCOTCH_dgraphBand           SCOTCH_NAME_PUBLIC (SCOTCH_dgraphBand)
 #define SCOTCH_dgraphBuild          SCOTCH_NAME_PUBLIC (SCOTCH_dgraphBuild)
@@ -1167,6 +1196,7 @@
 #define SCOTCH_dgraphMapExit        SCOTCH_NAME_PUBLIC (SCOTCH_dgraphMapExit)
 #define SCOTCH_dgraphMapInit        SCOTCH_NAME_PUBLIC (SCOTCH_dgraphMapInit)
 #define SCOTCH_dgraphMapSave        SCOTCH_NAME_PUBLIC (SCOTCH_dgraphMapSave)
+#define SCOTCH_dgraphMapStat        SCOTCH_NAME_PUBLIC (SCOTCH_dgraphMapStat)
 #define SCOTCH_dgraphMapView        SCOTCH_NAME_PUBLIC (SCOTCH_dgraphMapView)
 #define SCOTCH_dgraphOrderCblkDist  SCOTCH_NAME_PUBLIC (SCOTCH_dgraphOrderCblkDist)
 #define SCOTCH_dgraphOrderCompute   SCOTCH_NAME_PUBLIC (SCOTCH_dgraphOrderCompute)
@@ -1252,11 +1282,15 @@
 #define SCOTCH_graphRepart          SCOTCH_NAME_PUBLIC (SCOTCH_graphRepart)
 #define SCOTCH_graphRepartFixed     SCOTCH_NAME_PUBLIC (SCOTCH_graphRepartFixed)
 #define SCOTCH_graphSave            SCOTCH_NAME_PUBLIC (SCOTCH_graphSave)
+#define SCOTCH_graphSize            SCOTCH_NAME_PUBLIC (SCOTCH_graphSize)
 #define SCOTCH_graphSizeof          SCOTCH_NAME_PUBLIC (SCOTCH_graphSizeof)
 #define SCOTCH_graphStat            SCOTCH_NAME_PUBLIC (SCOTCH_graphStat)
 #define SCOTCH_graphTabLoad         SCOTCH_NAME_PUBLIC (SCOTCH_graphTabLoad)
+#define SCOTCH_graphTabSave         SCOTCH_NAME_PUBLIC (SCOTCH_graphTabSave)
 #define SCOTCH_mapAlloc             SCOTCH_NAME_PUBLIC (SCOTCH_mapAlloc)
 #define SCOTCH_mapSizeof            SCOTCH_NAME_PUBLIC (SCOTCH_mapSizeof)
+#define SCOTCH_memCur               SCOTCH_NAME_PUBLIC (SCOTCH_memCur)
+#define SCOTCH_memMax               SCOTCH_NAME_PUBLIC (SCOTCH_memMax)
 #define SCOTCH_meshAlloc            SCOTCH_NAME_PUBLIC (SCOTCH_meshAlloc)
 #define SCOTCH_meshBuild            SCOTCH_NAME_PUBLIC (SCOTCH_meshBuild)
 #define SCOTCH_meshCheck            SCOTCH_NAME_PUBLIC (SCOTCH_meshCheck)
@@ -1291,6 +1325,7 @@
 #define SCOTCH_randomReset          SCOTCH_NAME_PUBLIC (SCOTCH_randomReset)
 #define SCOTCH_randomSave           SCOTCH_NAME_PUBLIC (SCOTCH_randomSave)
 #define SCOTCH_randomSeed           SCOTCH_NAME_PUBLIC (SCOTCH_randomSeed)
+#define SCOTCH_randomVal            SCOTCH_NAME_PUBLIC (SCOTCH_randomVal)
 #define SCOTCH_stratAlloc           SCOTCH_NAME_PUBLIC (SCOTCH_stratAlloc)
 #define SCOTCH_stratArchBuild       SCOTCH_NAME_PUBLIC (SCOTCH_stratArchBuild)
 #define SCOTCH_stratDgraphClusterBuild SCOTCH_NAME_PUBLIC (SCOTCH_stratDgraphClusterBuild)
